Haiku catkeys — Translate Toolkit 1.9.0 documentation

Translate Toolkit 1.9.0

- Site
  - Features
  - Installation
  - Converters
  - Tools
  - Scripts
  - Use Cases
  - Supported formats
  - Translate Styleguide
  - Documentation
  - Building
  - Contributing
  - Translate Toolkit Developers Guide
  - API
  - Important Changes
  - History of the Translate Toolkit
  - License
- Page
  - Haiku catkeys
    - Links
- « Adobe Flex properties files
- TMX »

# Haiku catkeys

New in version 1.8.

Localisation for the Haiku operating system is done with a file format called catkeys. It is a bilingual file format.

## Links

- Some notes about the format
- Some example files